<?php

/**
 * @file
 * Administration forms and functions.
 */

/**
 * Admin settings form.
 */
function yammer_feeds_admin_settings() {
  $form['yammer_feeds_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Yammer settings'),
    '#description' => t('These settings will pull your yammer feeds and display them in a drupal block. To start with, please <a href="http://www.yammer.com/client_applications/new" target="_blank">create an application</a> and enter the public and secret keys in the fields below.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE
  );
  $form['yammer_feeds_settings']['yammer_feeds_application_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Yammer consumer (application) key'),
    '#description' => t('In this field, you have to enter the consumer (application) key of your application.'),
    '#default_value' => variable_get('yammer_feeds_application_key', ''),
  );
  $form['yammer_feeds_settings']['yammer_feeds_application_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Yammer consumer (application) secret'),
    '#description' => t('In this field, you have to enter the consumer (application) secret of your application.'),
    '#default_value' => variable_get('yammer_feeds_application_secret', ''),
  );
  $form['yammer_feeds_settings']['yammer_feeds_application_access_token'] = array(
    '#type' => 'hidden',
    '#default_value' => variable_get('yammer_feeds_application_access_token', ''),
  );
  $form['yammer_feeds_settings']['yammer_feeds_application_access_secret'] = array(
    '#type' => 'hidden',
    '#default_value' => variable_get('yammer_feeds_application_access_secret', ''),
  );
  $form['yammer_feeds_settings']['reset_settings'] = array(
    '#type' => 'hidden',
    '#default_value' => variable_get('reset_settings', ''),
  );
  return system_settings_form($form);
}

/**
 * Menu callback for authorizing a request for authentication.
 */
function yammer_feeds_add_verifier() {
  $keys = yammer_feeds_get_application_keys();
  extract($keys);
  module_load_include('inc', 'yammer_feeds', 'api/yammer_feeds.api');
  $yammer_obj = new YammerFeedYammerAPI($application_key, $application_secret);
  $oauth = $yammer_obj->getAuthorizationTokens();
  
  if (isset($oauth['oauth_token'])) {
    foreach ($oauth as $key => $value) {
      variable_set('yammer_feeds_' . $key, $value);
    }
    $yammer_obj->authorizeRequest($oauth['oauth_token']); 
  }
}

/**
 * Menu callback displaying an HTML form containing link to get verification
 * code and a form to submit it.
 */
function yammer_feeds_verification_form($form) {
  $keys = yammer_feeds_get_application_keys();
  extract($keys);
  if ($application_key || $application_secret) {
    $form['#prefix'] = t("To get a verification code for your Yammer application, !verification_url!", array('!verification_url' => l('click here', 'yammer-feeds/yammer-verifier', array('attributes' => array('target' => '_blank')))));
    $form['yammer_feeds_verification_code'] = array(
      '#type' => 'textfield',
      '#default_value' => '',
      '#title' => 'Code',
      '#description' => 'In this field, you have to enter the verification code obtained from the above link',
      '#size' => '4',
      '#required' => 'true',
    );
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Verify'),
    );
  }
  else {
    drupal_set_message(t("Please first enter your consumer key and secret for your application !url.", array('!url' => l('here', 'admin/config/services/yammer-feeds'))), 'error');
    drupal_access_denied();
  }
  return $form;
}

/**
 * Submit verification code.
 */
function yammer_feeds_verification_form_submit($form, &$form_state) {
  global $user;
  if (isset($form_state['values']['yammer_feeds_verification_code'])) {
    $verifier_code = $form_state['values']['yammer_feeds_verification_code'];
    variable_set('yammer_feeds_verifier_code', $verifier_code);
    variable_set('reset_settings', '1');
    $cache_id = 'yammer_feeds_messages_' . $user->uid;
    cache_clear_all($cache_id, 'cache');
  }
  $keys = yammer_feeds_get_application_keys();
  extract($keys);
  module_load_include('inc', 'yammer_feeds', 'api/yammer_feeds.api');
  $yammer_obj = new YammerFeedYammerAPI($application_key, $application_secret);
  $auth_tokens = $yammer_obj->getAccessToken($application_key, $application_secret, TRUE, $oauth_token, $oauth_token_secret, $verifier_code);
  
  if (is_array($auth_tokens)) {
    variable_set('yammer_feeds_application_access_token', $auth_tokens['oauth_token']);
    variable_set('yammer_feeds_application_access_secret', $auth_tokens['oauth_token_secret']);
    drupal_set_message(t('Authorization complete.'));
    drupal_goto();
  }
  else {
    drupal_set_message($auth_tokens, 'error');
  }
}